thru-core 0.2.13

Shared implementation for the Thru CLI
docs.rs failed to build thru-core-0.2.13
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.

Thru CLI core library — shared implementation for thru and thru-cli binaries.

This crate provides all CLI logic (argument parsing, command dispatch, configuration, crypto helpers, output formatting, etc.). The two binary crates (thru-cli and thru) are thin wrappers that call [run].